==> programy-3.8.5.tar.gz: programy-3.8.5/programy/clients/restful/sanic/config.py <==
"""
Copyright (c) 2016-2019 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""
from programy.clients.restful.config import RestConfiguration
from programy.utils.substitutions.substitues import Substitutions


class SanicRestConfiguration(RestConfiguration):

    def __init__(self, name):
        self._workers = 4
        RestConfiguration.__init__(self, name)

    @property
    def workers(self):
        return self._workers

    def check_for_license_keys(self, license_keys):
        RestConfiguration.check_for_license_keys(self, license_keys)

    def load_configuration_section(self, configuration_file, sanic, bot_root, subs: Substitutions = None):
        if sanic is not None:
            self._workers = configuration_file.get_option(sanic, "workers", missing_value=4, subs=subs)
            super(SanicRestConfiguration, self).load_configuration_section(configuration_file, sanic, bot_root, subs=subs)

    def to_yaml(self, data, defaults=True):
        if defaults is True:
            data['workers'] = 4
        else:
            data['workers'] = self._workers

        super(SanicRestConfiguration, self).to_yaml(data, defaults)

==> programy-5.0.tar.gz: programy-5.0/programy/clients/restful/sanic/config.py <==
"""
Copyright (c) 2016-2020 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""
from programy.clients.restful.config import RestConfiguration
from programy.utils.substitutions.substitues import Substitutions


class SanicRestConfiguration(RestConfiguration):

    def __init__(self, name):
        self._workers = 4
        RestConfiguration.__init__(self, name)

    @property
    def workers(self):
        return self._workers

    def load_configuration_section(self, configuration_file, section, bot_root, subs: Substitutions = None):

        assert section is not None

        self._workers = configuration_file.get_option(section, "workers", missing_value=4, subs=subs)
        super(SanicRestConfiguration, self).load_configuration_section(configuration_file, section, bot_root,
                                                                       subs=subs)

    def to_yaml(self, data, defaults=True):
        if defaults is True:
            data['workers'] = 4
        else:
            data['workers'] = self._workers

        super(SanicRestConfiguration, self).to_yaml(data, defaults)
